;+
; NAME:
;    grb_sed_oplot
;
; PURPOSE:
;   overplot SED of thr Gamma-Rays Extragalactic Background
;
; CATEGORY:
;
;
; CALLING SEQUENCE:
;
; 
; INPUTS:
;
;
; OPTIONAL INPUTS
;
;	
; KEYWORD PARAMETERS:
;
;
; OUTPUTS:
;
; PROCEDURE:
;
;
;
; EXAMPLE:
;
;
;
; MODIFICATION HISTORY:
;    06-Dec-2006 Written Herve Dole, IAS
;-
PRO grb_sed_oplot, color=color, wave=wave, freq=freq

COMMON plot_ebl, thick_plot, arrow_height, hsize

; Data from Strong et al., 2004, ApJ, 613, 956, table 3
;------------------------------------------------------
MeV =  [40., 60., 85., 125., 225., 400., 750., 1500., 3000., 7000., 15000., 35000.] ; Central energy in MeV
dMeV = [10., 10., 15., 25.,   75., 100., 250.,  500., 1000., 3000.,  5000., 15000.] ; dE in Mev

dIdE =  [8.40, 5.30, 2.22, 8.96e-1, 2.61e-1, 6.00e-2, 1.52e-2, 3.20e-3, 1.20e-3, 1.95e-4, 3.40e-5, 1.11e-5]*1.d-7 ; dI/dE in cm-2 sr-1 s-1 MeV-1
ddIdE = [2.54, 0.80, 0.22, 0.91e-1, 0.26e-1, 0.63e-2, 0.17e-2, 0.44e-3, 0.16e-3, 0.30e-4, 1.39e-5, 1.11e-5]*1.d-7 ; dI/dE in cm-2 sr-1 s-1 MeV-1

nelt = N_ELEMENTS(MeV)

; Convert into E2dI/dE
;---------------------
E2dIdE = MeV^2.*dIdE            ; now in MeV/cm2/sr/s
dE2dIdE = MeV^2.*ddIdE          ; now in MeV/cm2/sr/s

; Convert MeV/s into Watts
;-------------------------
; 1 MeV/s -> 1.602.d-13 W
Brtmp = E2dIdE *  1.602d-13     ; now in W/cm2/sr
dBrtmp = dE2dIdE *  1.602d-13   ; now in W/cm2/sr

; Convert into "regular" brightness nuInu in W/m2/sr
;---------------------------------------------------
sed_grb = Brtmp * 1.d4          ; now in W/m2/sr
dsed_grb = dBrtmp * 1.d4        ; now in W/m2/sr


; Convert MeV into Frequencies in GHz
;------------------------------------
nu_grb = MeV / 4.1357d-12       ; now in GHz
dnu_grb =  dMeV / 4.1357d-12    ; now in GHz

; Convert in Wavelengths microns
;-------------------------------
w_grb = 3.d8/nu_grb*1d-9*1d6
dw_grb = 3.d8/(nu_grb*1d9)^2.*dnu_grb*1.e9*1d6


IF KEYWORD_SET(freq) THEN BEGIN
    w_grb = nu_grb
    dw_grb = dnu_grb
ENDIF

; Actual oplot
;--------------
FOR i=0, nelt -1 DO BEGIN
    IF  sed_grb(i)/dsed_grb(i) LT 1.5 THEN BEGIN
        OPLOT, w_grb(i)+[-dw_grb(i), +dw_grb(i)], [sed_grb(i), sed_grb(i)], thick=thick_plot
        ARROW, w_grb(i),  sed_grb(i), w_grb(i),  sed_grb(i)/arrow_height, /DATA, /SOLID, HSIZE=hsize, thick=thick_plot
    ENDIF ELSE BEGIN
        OPLOT, w_grb(i)+[-dw_grb(i), +dw_grb(i)], [sed_grb(i), sed_grb(i)], thick=thick_plot
        OPLOT, [w_grb(i), w_grb(i)], sed_grb(i)+[-dsed_grb(i), +dsed_grb(i)], thick=thick_plot
    ENDELSE
ENDFOR


END
