;+
; NAME:
;      LOADCT_PLOT
;
; PURPOSE:
;      Load a simple color table with 8 colors, useful for plots
;      There are 8 colors: 0 is black, 7 is white, and between: red,
;      green, blue, ...
;
; CATEGORY:
;     plots
;
; CALLING SEQUENCE:
;     loadct_plot
; 
; INPUTS:
;     none
;	
; KEYWORD PARAMETERS:
;     /REVERSE: color = 0 is white and color=7 is black
;     /MODIFYCT: CREATE NEW COLOR TABLE
; OUTPUTS:
;     none
;
; PROCEDURE:
;     TVLCT
;
; EXAMPLE:
;     loadct_plot
;     loadct_plot, /reverse
;
; MODIFICATION HISTORY:
;     19-Jun-98 Written, H. Dole, IAS
;     Nov-1999: add modifyct HD
;     24-Nov-1999: add color=8: black HD
;-

PRO loadct_plot, reverse=reverse, modifyct=modifyct

; COLOR=0 : BLACK
;----------------
r = BYTARR(9)
g = r
b = r

; COLOR=1 : RED 
;--------------
r(1) = 255

; COLOR=2 : GREEN
;----------------
g(2) = 255

; COLOR=3 : BLUE 
;---------------
b(3) = 255

; COLOR=4 : 
;--------
r(4) = 255
g(4) = 255

; COLOR=5 : 
;--------
r(5) = 255
b(5) = 255

; COLOR=6 : 
;--------
g(6) = 255
b(6) = 255

; COLOR=7 : WHITE 
;----------------
r(7) = 255
g(7) = 255
b(7) = 255

; COLOR=8 : BLACK
;----------------
r(8) = 0
g(8) = 0
b(8) = 0


; REVERSE CASE
;-------------
IF KEYWORD_SET(reverse) THEN BEGIN
    r(0) = r(7)
    g(0) = g(7)
    b(0) = b(7)
    r(7) = 0
    g(7) = 0
    b(7) = 0
ENDIF

IF KEYWORD_SET(modifyct) THEN BEGIN
    rtot = findgen(256)
    gtot = rtot
    btot = rtot
    FOR i=0, 6 DO BEGIN
        step = 25
        imin = i*step
        imax = (i+1)*step
        rtot(imin:imax-1) = r(i) 
        gtot(imin:imax-1) = g(i) 
        btot(imin:imax-1) = b(i)
    ENDFOR
    color_table_title = 'H.Dole IAS Plots 1'
    ntab = 41
    IF KEYWORD_SET(reverse) THEN BEGIN
        color_table_title = 'H.Dole IAS Plots 2 (reverse)'
        rtot(255) = 0
        gtot(255) = 0
        btot(255) = 0
        rtot(0) = 255
        gtot(0) = 255
        btot(0) = 255
         ntab = 42
    ENDIF
    MODIFYCT, ntab, color_table_title, rtot, gtot, btot
ENDIF

TVLCT, r, g, b

END



