;+
; NAME:
;    plot_cosmic_backgrounds_sed
;
; PURPOSE:
;   PLOT the SED of the Cosmic Backgrounds: CIB+COB + optionally: CMB,
;   RadioB, UVB, XRB, GRB
;
;
; CATEGORY:
;
;
; CALLING SEQUENCE:
;    plot_cib_sed, ps=ps, eps=eps, png=png, color=color, freq=freq
; 
; INPUTS:
;  None, except files on disk
;
; KEYWORD PARAMETERS:
;    /freq: to plot the SED in ferquency [GHz] instead of wavelength
;    (microns, default)
;
;    /color for color plot (default is B&W)
;
;    /ps or /eps (both recommanded) or /png (not recommanded) for output
;
; OUTPUTS:
;   plot on file (recommanded) or screen (not recommanded)
;
; PROCEDURE:
;
;
;
; EXAMPLES:
;
; all examples are in the program: plot_cosmic_backgrounds_sed_all.pro
;
;   SIMPLE PLOTS OF COB+CIB:
;---------------------------
;    plot_cosmic_backgrounds_sed, /ps, /color
;    plot_cosmic_backgrounds_sed, /ps, /color, /kev
;    plot_cosmic_backgrounds_sed, /ps, /freq, /color
;
;   CMB+COB+CIB:
;--------------
;    plot_cosmic_backgrounds_sed, /ps, /color, /cmb
;    plot_cosmic_backgrounds_sed, /ps, /color, /cmb, /kev
;    plot_cosmic_backgrounds_sed, /ps, /freq, /color, /cmb
;
; MODIFICATION HISTORY:
;   04-Dec-2006 Written Herve Dole, IAS
;   20-Dec-2006 Add /kev for top x axis HD
;
;-
PRO  plot_cosmic_backgrounds_sed, ps=ps, eps=eps, png=png, color=color, freq=freq, wave=wave, kev=kev, cmb=cmb, radiob=radiob, uvb=uvb, xrb=xrb, grb=grb

; STILL TO DO:
; - FUV Bkg
; - Radio Bkg

; Define Commons Here
;---------------------
COMMON plot_ebl, thick_plot, arrow_height, hsize, symsize, thick_symbol
COMMON plot_ebl_path, path_home, path_dat


; Path: PLEASE DEFINE HERE YOUR FAVORITE LOCATION
;------------------------------------------------
path_home = '$HOME/develop/obs/CIB/sed/' ; <- put the path HERE
;path_home = './' ; <- put the path HERE
; Path where scii files for some CIB+EBL measurements
path_dat = path_home + 'ebl_data/'

; Path for output ps and png files; PLEASE create these directories first
path_ps =  path_home +'/ps/'
path_gif = path_home +'/gif/'



; Bottom Scale (plot) in Wavelengths or Frequency ?
;-------------------------------------------------
wave = 1                        ; default: in wavelength
IF KEYWORD_SET(freq) THEN BEGIN
    freq = 1
    wave = 0
ENDIF


; PLOT
;-----
; Output Image Type
;------------------
; Image
flag_image = 1
IF KEYWORD_SET(ps) OR  KEYWORD_SET(eps) THEN flag_image = 0
; Plot
IF flag_image EQ 1 THEN plot = 1
IF KEYWORD_SET(ps) OR KEYWORD_SET(eps) THEN plot = 1
; path
suffix = '.ps'
prefix = path_ps
IF flag_image EQ 1 THEN prefix = path_gif
IF KEYWORD_SET(eps) THEN suffix = '.eps'
IF KEYWORD_SET(gif) THEN suffix = '.gif'
IF KEYWORD_SET(jpg) THEN suffix = '.jpg'
IF KEYWORD_SET(png) THEN suffix = '.png'


; Define Common Plot Feature
;---------------------------
thick_plot = 3.5
arrow_height = 1.55
hsize = 150
symsize = 1.5
thick_symbol = 2

IF (KEYWORD_SET(uvb) OR KEYWORD_SET(xrb) OR KEYWORD_SET(grb) OR KEYWORD_SET(radiob)) THEN BEGIN
    symsize = 0.5
    thick_symbol = 1.
ENDIF

; SET UP PLOT
;------------
!p.charsize=1.2
charsize = 1.0
charsize_sml = 0.8
thick_plot2 = 8.

IF KEYWORD_SET(png) THEN !p.charsize=2.5

IF KEYWORD_SET(color) THEN BEGIN
    LOADCT_PLOT
    red = 1
    green = 2
    blue = 3
    yellow = 4
    purple= 5
    suffix = '.color'+ suffix
ENDIF

IF KEYWORD_SET(freq) THEN suffix = '.freq'+suffix
IF KEYWORD_SET(kev) THEN suffix = '.kev'+suffix
IF KEYWORD_SET(cmb) THEN suffix = '.cmb'+suffix
IF KEYWORD_SET(radiob) THEN suffix = '.radio'+suffix
IF KEYWORD_SET(uvb) THEN suffix = '.uvb'+suffix
IF KEYWORD_SET(xrb) THEN suffix = '.xrb'+suffix
IF KEYWORD_SET(grb) THEN suffix = '.grb'+suffix


file2write = 'ebl_sed'


; GIF/JPG/PNG/PS/EPS
;-------------------
file2write = prefix + file2write + suffix
IF KEYWORD_SET(ps) OR KEYWORD_SET(eps) THEN BEGIN
    SET_PLOT, 'ps'
    DEVICE, file=file2write, ENCAPSULATED = KEYWORD_SET(eps), /palatino, isolatin=0, COLOR=KEYWORD_SET(color) 
    !p.font=0
ENDIF



; Titles
;-------
xtit = 'Wavelength !ml!x [!mm!xm]'
xtit2 = 'Frequency !mn!x [GHz]'
IF KEYWORD_SET(freq) THEN BEGIN
    xtit2 = 'Wavelength !ml!x [!mm!xm]'
    xtit = 'Frequency !mn!x [GHz]'
ENDIF
IF KEYWORD_SET(kev) THEN BEGIN
    xtit2 = 'Energy [keV]'
ENDIF
ytit = 'Brightness !mn!xI!l!mn!x!n [W m !u-2!n sr!u-1!n]' ;'W m !u-2!n sr!u-1!n'    ; '!mn!xI!l!mn!x!n [W m !u-2!n sr!u-1!n]'

; Position for Plot
;------------------
!p.position=[0.11, 0.11, 0.91, 0.89]

; Plot Range
;-----------
; wavelength in MICRONS
xmin = 0.1                      ; in microns
xmax = 1.e3                     ; in microns
ymin = 2.e-10                   ; in W/m2/sr
ymax = 1.e-7                    ; in W/m2/sr

; Frequencies in GHz
IF KEYWORD_SET(freq) THEN BEGIN
    xmin = 1.e2                 ; in GHz
    xmax = 1.e7                 ; in GHz
ENDIF

; Range using other options

IF KEYWORD_SET(cmb) THEN BEGIN
    ymin = 1.e-10               ; in W/m2/sr
    ymax = 1.e-6                ; in W/m2/sr
    IF KEYWORD_SET(wave) THEN BEGIN
        xmin = 0.1              ; in microns
        xmax = 1.e6             ; in microns
    ENDIF
    IF KEYWORD_SET(freq) THEN BEGIN
        xmin = 1.               ; in GHz
        xmax = 1.e7             ; in GHz
    ENDIF

ENDIF

IF KEYWORD_SET(radiob) THEN BEGIN
    xmax = 1.e5                 ; in microns
    ymin = 1.e-14               ; in W/m2/sr
    IF KEYWORD_SET(freq) THEN BEGIN
        xmin = 1.               ; in GHz
    ENDIF
ENDIF

IF KEYWORD_SET(uvb) THEN BEGIN
    IF KEYWORD_SET(wave) THEN BEGIN
        xmin = 1.e-2            ; in microns
    ENDIF
    IF KEYWORD_SET(freq) THEN BEGIN
        xmax = 1.e7             ; in GHz
    ENDIF
ENDIF

IF KEYWORD_SET(xrb) THEN BEGIN
    ymin = 1.e-11               ; in W/m2/sr
    IF KEYWORD_SET(wave) THEN BEGIN
        xmin = 1.e-5            ; in microns
    ENDIF
    IF KEYWORD_SET(freq) THEN BEGIN
        xmax = 1.e10            ; in GHz
    ENDIF
ENDIF

IF KEYWORD_SET(grb) THEN BEGIN
    ymin = 1.e-13               ; in W/m2/sr
    IF KEYWORD_SET(wave) THEN BEGIN
        xmin = 1.e-12           ; in microns
    ENDIF
    IF KEYWORD_SET(freq) THEN BEGIN
        xmax = 1.e17            ; in GHz
    ENDIF
ENDIF



; Plot the frame
;---------------
plot, [xmin, xmax], [1.E-14, 1.e-14], yr=[ymin,ymax], /yl, /ys, /xl, xr=[xmin, xmax], xtit=xtit, ytit=ytit, thick=thick_plot2, xthick=thick_plot, ythick=thick_plot,  xs=8+1

; Top x Axis and Title
;---------------------
xr = 3.e5/10.^!x.crange         ; default conversion wave(um)<->freq(GHz)
IF KEYWORD_SET(kev) THEN BEGIN  ; optional conversion to keV
    IF KEYWORD_SET(wave) THEN BEGIN ; convert wave(um)->energy(keV)
        xr = 4.1357d-9 * 3.e5/10.^!x.crange
    ENDIF
    IF KEYWORD_SET(freq) THEN BEGIN ; convert freq(GHz)->energy(keV)
        xr = 4.1357d-9 * 10.^!x.crange ; now in keV
    ENDIF
ENDIF
axis, xaxis=1, xrange=xr, xthick=thick_plot, xs=1, /xl
XYOUTS, 0.5, 0.96, xtit2, /NORMAL, ALIGN=0.5


; OPLOT THE CIB + COB SED
;-----------------------
cib_cob_sed_oplot, color=KEYWORD_SET(color), xmin=xmin, wave=KEYWORD_SET(wave), freq=KEYWORD_SET(freq)


; OPLOT CMB
;----------
IF KEYWORD_SET(cmb) THEN BEGIN
    cmb_sed_oplot, color=KEYWORD_SET(color), wave=KEYWORD_SET(wave), freq=KEYWORD_SET(freq)
ENDIF

; OPLOT RADIO BACKGROUND
;-----------------------
; XXX TBD
;IF KEYWORD_SET(radiob) THEN BEGIN
;radiobkg_sed_oplot, color=KEYWORD_SET(color), wave=KEYWORD_SET(wave), freq=KEYWORD_SET(freq)
;ENDIF


; OPLOT UV BACKGROUND
;--------------------
IF KEYWORD_SET(uvb) THEN BEGIN
    uvb_sed_oplot, color=KEYWORD_SET(color), wave=KEYWORD_SET(wave), freq=KEYWORD_SET(freq)
ENDIF


; OPLOT XRB
;----------
IF KEYWORD_SET(xrb) THEN BEGIN
    xrb_sed_oplot, color=KEYWORD_SET(color),  wave=KEYWORD_SET(wave), freq=KEYWORD_SET(freq)
ENDIF


; OPLOT GAMMA BACKGROUND
;-----------------------
IF KEYWORD_SET(grb) THEN BEGIN
    grb_sed_oplot, color=KEYWORD_SET(color), wave=KEYWORD_SET(wave), freq=KEYWORD_SET(freq)
ENDIF


; Close Graphics File
;--------------------

; GIF/JPG/PNG/PS/EPS
;-------------------
IF KEYWORD_SET(gif) THEN BEGIN
    PLOT_gif, file2write
ENDIF
IF KEYWORD_SET(jpg) THEN BEGIN
    PLOT_jpg, file2write
ENDIF
IF KEYWORD_SET(png) THEN BEGIN
    PLOT_png, file2write
ENDIF
IF KEYWORD_SET(ps) OR KEYWORD_SET(eps) THEN BEGIN
    DEVICE, /CLOSE
    SET_PLOT, 'X'
    !p.font=1
    print, ' wrote: '+file2write
ENDIF




END

; For Public Distribution:
tar -cvzf ebl_sed_hdole.tgz sed/plot_cosmic_backgrounds_sed.pro sed/plot_cosmic_backgrounds_sed_all.pro sed/*sed_oplot.pro sed/ebl_data sed/planck.pro sed/loadct_plot.pro sed/symbol*.pro sed/ps/ sed/gif/ sed/convert*csh

