;+
; NAME:
;    xrb_sed_oplot
;
; PURPOSE:
;   overplot SED of the X-Ray Extragalactic Background
;
; CATEGORY:
;
;
; CALLING SEQUENCE:
;
; 
; INPUTS:
;
;
; OPTIONAL INPUTS
;
;	
; KEYWORD PARAMETERS:
;
;
; OUTPUTS:
;
; PROCEDURE:
;
;
;
; EXAMPLE:
;
;
;
; MODIFICATION HISTORY:
;    07-Dec-2006 Written Herve Dole, IAS
;    03-Jan-2006 updated with R Gilli's data HD
;
;-
PRO xrb_sed_oplot, color=color, wave=wave, freq=freq

; Commons for plots
;------------------
COMMON plot_ebl, thick_plot, arrow_height, hsize, symsize, thick_symbol
COMMON plot_ebl_path, path_home, path_dat

; Data from Hickox & Markevitch, 2006, ApJ, 645, 95
;--------------------------------------------------

; Energies
;---------
keV = [1.5, 5.]                 ; in keV
dkeV = [0.5, 3.]                ; in keV

; XRB
;----
sed_xrb_raw = [4.6, 17.]*1.e-12     ;in erg cm-2 s-1 deg-2
esed_xrb_raw = [0.3, 2.]*1.e-12     ;in erg cm-2 s-1 deg-2

; Convert in W/m2/sr
;--------------------
sed_xrb =  sed_xrb_raw * 1.e-7 * 1.e4 * (1/!DTOR)^2. ; now in W/m2/sr
esed_xrb =  esed_xrb_raw * 1.e-7 * 1.e4 * (1/!DTOR)^2. ; now in W/m2/sr

; Convert keV into Frequencies in GHz
;------------------------------------
nu_xrb = keV / 4.1357d-12 * 1d-3       ; now in GHz
dnu_xrb =  dkeV / 4.1357d-12 * 1d-3   ; now in GHz

; Convert in Wavelengths microns
;-------------------------------
w_xrb = 3.d8/nu_xrb*1d-9*1d6
dw_xrb = 3.d8/(nu_xrb*1d9)^2.*dnu_xrb*1.e9*1d6

nelt = N_ELEMENTS(w_xrb)

IF KEYWORD_SET(freq) THEN BEGIN
    w_xrb = nu_xrb
    dw_xrb = dnu_xrb
ENDIF

; Actual oplot
;--------------
FOR i=0, nelt -1 DO BEGIN
    OPLOT, w_xrb(i)*[1., 1.], sed_xrb(i)+esed_xrb(i)*[-1., 1.]/2.
    OPLOT, w_xrb(i) + dw_xrb(i)*[-1., 1.]/2., sed_xrb(i)*[1., 1.]
ENDFOR



; Data kindly sent by Roberto Gilli on 03Jan2007
;-----------------------------------------------
;file            reference
;heao1.dat       Gruber 1992; Gruber et al. 1999, ApJ, 520, 125
;gendreau.dat    Gendreau et al. 1995, PASJ, 47, L5
;takamitsu.dat   Miyaji et al. 1998, A&A, 334, L13       
;watanabe.dat    Watanabe et al. 1997, AIP Conf Proc. 410, 1223
;the file format is:
;e 1 de 2 f 3 df 4
;in heao1.dat and takamitsu.dat 
;f and df are in keV/cm2/s/sr
;in gendreau.dat and watanabe.dat 
;f and df are in phot/cm2/s/sr/keV
;The heao1.dat file contains also datapoints from the balloon experiment
;by Fukada et al. 1975, Nature, 254, 398

; HEAO1 Gruber92 & Gruber+99
;---------------------------
xfile = path_dat + 'heao1.dat'
READCOL, xfile, e, de, f, df

; Convert keV/cm2/s/sr in W/m2/sr
;--------------------------------
sed_xrb = f * 1.602d-16 * 1d4 ; now in W/m2/sr
esed_xrb = df * 1.602d-16 * 1d4 ; now in W/m2/sr

; Convert keV into Frequencies in GHz
;------------------------------------
nu_xrb = e / 4.1357d-12 * 1d-3       ; now in GHz
dnu_xrb =  de / 4.1357d-12 * 1d-3   ; now in GHz

; Convert in Wavelengths microns
;-------------------------------
w_xrb = 3.d8/nu_xrb*1d-9*1d6
dw_xrb = 3.d8/(nu_xrb*1d9)^2.*dnu_xrb*1.e9*1d6

nelt = N_ELEMENTS(w_xrb)

IF KEYWORD_SET(freq) THEN BEGIN
    w_xrb = nu_xrb
    dw_xrb = dnu_xrb
ENDIF

; Actual oplot
;--------------
FOR i=0, nelt -1 DO BEGIN
    OPLOT, w_xrb(i)*[1., 1.], sed_xrb(i)+esed_xrb(i)*[-1., 1.]/2., thick=thick_plot
    OPLOT, w_xrb(i) + dw_xrb(i)*[-1., 1.]/2., sed_xrb(i)*[1., 1.], thick=thick_plot
ENDFOR




; Gendreau+95
;------------
xfile = path_dat + 'gendreau.dat'
READCOL, xfile, e, de, dIdE, ddIdE

; Convert into E2dI/dE
;---------------------
E2dIdE = e^2.*dIdE            ; now in keV/cm2/sr/s
dE2dIdE = e^2.*ddIdE          ; now in keV/cm2/sr/s

; Convert E2dI/dE keV*s/cm2/sr in W/m2/sr
;-------------------------------------------
sed_xrb = E2dIdE * 1.602d-16 * 1d4 ; now in W/m2/sr
esed_xrb = dE2dIdE * 1.602d-16 * 1d4 ; now in W/m2/sr

; Convert keV into Frequencies in GHz
;------------------------------------
nu_xrb = e / 4.1357d-12 * 1d-3       ; now in GHz
dnu_xrb =  de / 4.1357d-12 * 1d-3   ; now in GHz

; Convert in Wavelengths microns
;-------------------------------
w_xrb = 3.d8/nu_xrb*1d-9*1d6
dw_xrb = 3.d8/(nu_xrb*1d9)^2.*dnu_xrb*1.e9*1d6

nelt = N_ELEMENTS(w_xrb)

IF KEYWORD_SET(freq) THEN BEGIN
    w_xrb = nu_xrb
    dw_xrb = dnu_xrb
ENDIF

; Actual oplot
;--------------
FOR i=0, nelt -1 DO BEGIN
    OPLOT, w_xrb(i)*[1., 1.], sed_xrb(i)+esed_xrb(i)*[-1., 1.]/2., thick=thick_plot
    OPLOT, w_xrb(i) + dw_xrb(i)*[-1., 1.]/2., sed_xrb(i)*[1., 1.], thick=thick_plot
ENDFOR



; Watanabe+97
;------------
xfile = path_dat + 'watanabe.dat'
READCOL, xfile, e, de, dIdE, ddIdE

; Convert into E2dI/dE
;---------------------
E2dIdE = e^2.*dIdE            ; now in keV/cm2/sr/s
dE2dIdE = e^2.*ddIdE          ; now in keV/cm2/sr/s

; Convert E2dI/dE keV*s/cm2/sr in W/m2/sr
;-------------------------------------------
sed_xrb = E2dIdE * 1.602d-16 * 1d4 ; now in W/m2/sr
esed_xrb = dE2dIdE * 1.602d-16 * 1d4 ; now in W/m2/sr

; Convert keV into Frequencies in GHz
;------------------------------------
nu_xrb = e / 4.1357d-12 * 1d-3       ; now in GHz
dnu_xrb =  de / 4.1357d-12 * 1d-3   ; now in GHz

; Convert in Wavelengths microns
;-------------------------------
w_xrb = 3.d8/nu_xrb*1d-9*1d6
dw_xrb = 3.d8/(nu_xrb*1d9)^2.*dnu_xrb*1.e9*1d6

nelt = N_ELEMENTS(w_xrb)

IF KEYWORD_SET(freq) THEN BEGIN
    w_xrb = nu_xrb
    dw_xrb = dnu_xrb
ENDIF

; Actual oplot
;--------------
FOR i=0, nelt -1 DO BEGIN
    OPLOT, w_xrb(i)*[1., 1.], sed_xrb(i)+esed_xrb(i)*[-1., 1.]/2., thick=thick_plot
    OPLOT, w_xrb(i) + dw_xrb(i)*[-1., 1.]/2., sed_xrb(i)*[1., 1.], thick=thick_plot
ENDFOR






END
